@@ -25,11 +25,10 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QTextCodec>
+#include <QApplication>
 
-#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kurlrequester.h>
 
 ExportDialog::ExportDialog(QWidget *parent)
         : KDialog(parent), m_mainwidget(new ExportWidget(this))
@@ -37,7 +36,7 @@ ExportDialog::ExportDialog(QWidget *parent)
     setCaption(i18n("Export Sheet to HTML"));
     setButtons(Ok | Cancel);
     setDefaultButton(KDialog::Cancel);
-    kapp->restoreOverrideCursor();
+    QApplication::restoreOverrideCursor();
 
     connect(m_mainwidget->mCustomButton, SIGNAL(toggled(bool)),
             m_mainwidget->mCustomURL, SLOT(setEnabled(bool)));
@@ -66,7 +65,7 @@ void ExportDialog::selectAll()
 
 ExportDialog::~ExportDialog()
 {
-    kapp->setOverrideCursor(Qt::WaitCursor);
+    QApplication::setOverrideCursor(Qt::WaitCursor);
 }
 
 QTextCodec *ExportDialog::encoding() const
