@@ -71,7 +71,7 @@ public:
 
     virtual void setEnabled(bool enabled);
 
-public slots:
+public Q_SLOTS:
     inline void setDataSource(const QString &ds) {
         KexiFormDataItemInterface::setDataSource(ds);
     }
