@@ -39,10 +39,8 @@
 #include "kexiformscrollview.h"
 
 #include <formeditor/objecttree.h>
-//2.0 #include <formeditor/formmanager.h>
 #include <formeditor/widgetlibrary.h>
 #include <widget/dataviewcommon/kexidataawareobjectiface.h>
-#include <widget/kexiscrollview.h>
 #include <kexiutils/utils.h>
 #include <kexi_global.h>
 
@@ -102,11 +100,10 @@ public:
     //! a subset of orderedFocusWidgets mapped to indices
     QHash<KexiDataItemInterface*, uint> indicesForDataAwareWidgets;
     QList<QWidget*>::iterator orderedFocusWidgetsIterator;
-//2.0    QPixmap buffer; //!< stores grabbed entire form's area for redraw
     QRect prev_rect; //!< previously selected rectangle
-    bool autoTabStops : 1;
-    bool popupFocused : 1; //!< used in KexiDBForm::eventFilter()
-    bool orderedFocusWidgetsIteratorInitialized : 1;
+    bool autoTabStops;
+    bool popupFocused; //!< used in KexiDBForm::eventFilter()
+    bool orderedFocusWidgetsIteratorInitialized;
 };
 
 //========================
@@ -117,7 +114,6 @@ KexiDBForm::KexiDBForm(QWidget *parent, KexiDataAwareObjectInterface* dataAwareO
         , d(new Private())
 {
     installEventFilter(this);
-//test setDisplayMode( KexiGradientWidget::SimpleGradient );
     editedItem = 0;
     d->dataAwareObject = dataAwareObject;
     KexiDataItemInterface::setHasFocusableWidget(false);
@@ -131,7 +127,7 @@ KexiDBForm::KexiDBForm(QWidget *parent, KexiDataAwareObjectInterface* dataAwareO
 
 KexiDBForm::~KexiDBForm()
 {
-    kDebug() << "close";
+    //kDebug() << "close";
     delete d;
 }
 
@@ -140,179 +136,6 @@ KexiDataAwareObjectInterface* KexiDBForm::dataAwareObject() const
     return d->dataAwareObject;
 }
 
-#if 0 //2.0
-//repaint all children widgets
-static void repaintAll(QWidget *w)
-{
-    const QList<QWidget*> list(w->findChildren<QWidget*>());
-    foreach(QWidget *widget, list) {
-        widget->repaint();
-    }
-}
-#endif
-
-void
-KexiDBForm::drawRect(const QRect& r, int type)
-{
-    QList<QRect> l;
-    l.append(r);
-    drawRects(l, type);
-}
-
-void
-KexiDBForm::drawRects(const QList<QRect> &list, int type)
-{
-    Q_UNUSED(list);
-    Q_UNUSED(type);
-#if 0 // 2.0
-    QPainter p;
-    p.begin(this);
-#ifdef __GNUC__
-#warning ??? p.begin(this, true);
-#else
-#pragma WARNING( ??? p.begin(this, true); )
-#endif
-    bool unclipped = testAttribute(Qt::WA_PaintUnclipped);
-    setAttribute(Qt::WA_PaintUnclipped, true);
-
-    if (d->prev_rect.isValid()) {
-        //redraw prev. selection's rectangle
-        p.drawPixmap(QPoint(d->prev_rect.x() - 2, d->prev_rect.y() - 2), d->buffer,
-                     QRect(d->prev_rect.x() - 2, d->prev_rect.y() - 2, d->prev_rect.width() + 4, d->prev_rect.height() + 4));
-    }
-    p.setBrush(Qt::NoBrush);
-    if (type == 1) // selection rect
-        p.setPen(QPen(Qt::white, 1, Qt::DotLine));
-    else if (type == 2) // insert rect
-        p.setPen(QPen(Qt::white, 2));
-    p.setCompositionMode(QPainter::CompositionMode_Xor);
-
-    d->prev_rect = QRect();
-    foreach(const QRect& r, list) {
-        p.drawRect(r);
-        if (d->prev_rect.isValid())
-            d->prev_rect = d->prev_rect.unite(r);
-        else
-            d->prev_rect = r;
-    }
-
-    if (!unclipped)
-        setAttribute(Qt::WA_PaintUnclipped, false);
-    p.end();
-#endif
-}
-
-void
-KexiDBForm::initBuffer()
-{
-#if 0 //2.0
-    repaintAll(this);
-    //Qt4 d->buffer.resize( width(), height() );
-    d->buffer = QPixmap::grabWindow(winId());
-    d->prev_rect = QRect();
-#endif
-}
-
-void
-KexiDBForm::clearForm()
-{
-#if 0 //2.0
-    QPainter p;
-#ifdef __GNUC__
-#warning ?? p.begin(this, true);
-#else
-#pragma WARNING( ?? p.begin(this, true); )
-#endif
-    p.begin(this);
-    bool unclipped = testAttribute(Qt::WA_PaintUnclipped);
-    setAttribute(Qt::WA_PaintUnclipped, true);
-
-    //redraw entire form surface
-    p.drawPixmap(QPoint(0, 0), d->buffer, QRect(0, 0, d->buffer.width(), d->buffer.height()));
-
-    if (!unclipped)
-        setAttribute(Qt::WA_PaintUnclipped, false);
-
-    p.end();
-    repaintAll(this);
-#endif
-}
-
-void
-KexiDBForm::highlightWidgets(QWidget *from, QWidget *to)//, const QPoint &point)
-{
-    Q_UNUSED(from);
-    Q_UNUSED(to);
-#if 0 //2.0
-    QPoint fromPoint, toPoint;
-    if (from && from->parentWidget() && (from != this))
-        fromPoint = from->parentWidget()->mapTo(this, from->pos());
-    if (to && to->parentWidget() && (to != this))
-        toPoint = to->parentWidget()->mapTo(this, to->pos());
-
-    QPainter p;
-#ifdef __GNUC__
-#warning ??? p.begin(this, true);
-#else
-#pragma WARNING( ??? p.begin(this, true); )
-#endif
-    p.begin(this);
-    bool unclipped = testAttribute(Qt::WA_PaintUnclipped);
-    setAttribute(Qt::WA_PaintUnclipped, true);
-
-    if (d->prev_rect.isValid()) {
-        //redraw prev. selection's rectangle
-        p.drawPixmap(QPoint(d->prev_rect.x(), d->prev_rect.y()), d->buffer,
-                     QRect(d->prev_rect.x(), d->prev_rect.y(), d->prev_rect.width(), d->prev_rect.height()));
-    }
-
-    p.setPen(QPen(Qt::red, 2));
-
-    if (to) {
-        QPixmap pix1 = QPixmap::grabWidget(from);
-        QPixmap pix2 = QPixmap::grabWidget(to);
-
-        if ((from != this) && (to != this))
-            p.drawLine(from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()));
-
-        p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
-        p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
-
-        if (to == this)
-            p.drawRoundRect(2, 2, width() - 4, height() - 4, 4, 4);
-        else
-            p.drawRoundRect(toPoint.x(), toPoint.y(), to->width(), to->height(), 5, 5);
-    }
-
-    if (from == this)
-        p.drawRoundRect(2, 2, width() - 4, height() - 4, 4, 4);
-    else
-        p.drawRoundRect(fromPoint.x(),  fromPoint.y(), from->width(), from->height(), 5, 5);
-
-    if ((to == this) || (from == this))
-        d->prev_rect = QRect(0, 0, d->buffer.width(), d->buffer.height());
-    else if (to) {
-        d->prev_rect.setX((fromPoint.x() < toPoint.x()) ? (fromPoint.x() - 5) : (toPoint.x() - 5));
-        d->prev_rect.setY((fromPoint.y() < toPoint.y()) ? (fromPoint.y() - 5) : (toPoint.y() - 5));
-        d->prev_rect.setRight((fromPoint.x() < toPoint.x()) ? (toPoint.x() + to->width() + 10) : (fromPoint.x() + from->width() + 10));
-        d->prev_rect.setBottom((fromPoint.y() < toPoint.y()) ? (toPoint.y() + to->height() + 10) : (fromPoint.y() + from->height() + 10)) ;
-    } else
-        d->prev_rect = QRect(fromPoint.x() - 5,  fromPoint.y() - 5, from->width() + 10, from->height() + 10);
-
-    if (!unclipped)
-        setAttribute(Qt::WA_PaintUnclipped, false);
-
-    p.end();
-#endif
-}
-
-QSize
-KexiDBForm::sizeHint() const
-{
-    //todo: find better size (user configured?)
-    return QSize(400, 300);
-}
-
 void KexiDBForm::setInvalidState(const QString& displayText)
 {
     Q_UNUSED(displayText);
@@ -343,17 +166,13 @@ QList<QWidget*>* KexiDBForm::orderedDataAwareWidgets() const
 void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
 {
     QWidget *fromWidget = 0;
-    //QWidget *topLevelWidget = form->widget()->topLevelWidget();
-//js form->updateTabStopsOrder(); //certain widgets can have now updated focusPolicy properties, fix this
     uint numberOfDataAwareWidgets = 0;
-// if (d->orderedFocusWidgets.isEmpty()) {
     //generate a new list
     foreach (KFormDesigner::ObjectTreeItem* titem, *form->tabStops()) {
         if (titem->widget()->focusPolicy() & Qt::TabFocus) {
             if (fromWidget) {
                 kDebug() << "tab order: "
-                    << fromWidget->objectName()
-                    << " -> " << titem->widget()->objectName();
+                    << fromWidget->objectName() << "->" << titem->widget()->objectName();
             }
             fromWidget = titem->widget();
             d->orderedFocusWidgets.append(titem->widget());
@@ -375,16 +194,14 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
             kDebug() << "#" << numberOfDataAwareWidgets << ": "
                 << dataItem->dataSource() << " (" << titem->widget()->objectName() << ")";
 
-// /*! @todo d->indicesForDataAwareWidgets SHOULD NOT BE UPDATED HERE BECAUSE
-// THERE CAN BE ALSO NON-TABSTOP DATA WIDGETS!
-// */
+//! @todo d->indicesForDataAwareWidgets SHOULD NOT BE UPDATED HERE BECAUSE
+//! THERE CAN BE ALSO NON-TABSTOP DATA WIDGETS!
             d->indicesForDataAwareWidgets.insert(dataItem, numberOfDataAwareWidgets);
             numberOfDataAwareWidgets++;
 
             d->orderedDataAwareWidgets.append(titem->widget());
         }
     }//for
-// }
     /* else {
         //restore ordering
         for (QPtrListIterator<QWidget> it(d->orderedFocusWidgets); it.current(); ++it) {
@@ -555,7 +372,6 @@ bool KexiDBForm::eventFilter(QObject * watched, QEvent * e)
                 //kDebug() << realWidget->objectName();
 
                 // find next/prev widget to focus
-                //QWidget *widgetToUnfocus = realWidget;
                 QWidget *widgetToFocus = 0;
                 bool wasAtFirstWidget = false; //used to protect against infinite loop
                 while (true) {
@@ -611,15 +427,8 @@ bool KexiDBForm::eventFilter(QObject * watched, QEvent * e)
 
                 if (widgetToFocus && d->dataAwareObject->acceptEditor()) {
                     if (tab) {
-                        //try to accept this will validate the current input (if any)
-//2.0 didn't work                        KexiUtils::unsetFocusWithReason(widgetToUnfocus, Qt::TabFocusReason);
-//2.0 didn't work                        KexiUtils::setFocusWithReason(widgetToFocus, Qt::TabFocusReason);
                         widgetToFocus->setFocus();
                         //kDebug() << "focusing " << widgetToFocus->objectName();
-                    } else {//backtab
-//2.0 didn't work                        KexiUtils::unsetFocusWithReason(widgetToUnfocus, Qt::BacktabFocusReason);
-                        //set focus, see above note
-//2.0 didn't work                        KexiUtils::setFocusWithReason(*d->orderedFocusWidgetsIterator, Qt::BacktabFocusReason);
                         (*d->orderedFocusWidgetsIterator)->setFocus();
                         //kDebug() << "focusing " << (*d->orderedFocusWidgetsIterator)->objectName();
                     }
@@ -670,14 +479,11 @@ bool KexiDBForm::eventFilter(QObject * watched, QEvent * e)
         }
     } else if (e->type() == QEvent::FocusOut) {
         if (static_cast<QFocusEvent*>(e)->reason() == Qt::PopupFocusReason) {
-            //d->widgetFocusedBeforePopup = (QWidget*)watched;
             d->popupFocused = true;
         } else {
             d->popupFocused = false;
         }
-//   d->widgetFocusedBeforePopup = 0;
 //  kDebug() << "e->type()==QEvent::FocusOut " << watched->className() << " " <<watched->name();
-//  UNSET_FOCUS_USING_REASON(watched, static_cast<QFocusEvent*>(e)->reason());
     }
     return QWidget::eventFilter(watched, e);
 }
@@ -728,8 +534,8 @@ void KexiDBForm::clear()
 
 bool KexiDBForm::isPreviewing() const
 {
-    return dynamic_cast<KexiScrollView*>(d->dataAwareObject)
-           ? dynamic_cast<KexiScrollView*>(d->dataAwareObject)->isPreviewing() : false;
+    return dynamic_cast<KexiFormScrollView*>(d->dataAwareObject)
+           ? dynamic_cast<KexiFormScrollView*>(d->dataAwareObject)->isPreviewing() : false;
 }
 
 void KexiDBForm::dragMoveEvent(QDragMoveEvent *e)
@@ -744,34 +550,16 @@ void KexiDBForm::dropEvent(QDropEvent *e)
     emit handleDropEvent(e);
 }
 
-/*void KexiDBForm::setCursor(const QCursor & cursor)
+void KexiDBForm::paintEvent(QPaintEvent *e)
 {
-    //js: empty, to avoid fscking problems with random cursors!
-    //! @todo?
-        
-    if (form() && form()->state() == KFormDesigner::Form::WidgetInserting) { //exception
-        QWidget::setCursor(cursor);
+    QWidget::paintEvent(e);
+    if (isPreviewing()) {
+        // Force background in styles like Oxygen
+        QPainter p;
+        p.begin(this);
+        p.fillRect(e->rect(), palette().brush(backgroundRole()));
+        p.end();
     }
-}*/
-
-//! @todo: Qt4? XORed resize rectangles instead of black widgets
-/*
-void KexiDBForm::paintEvent( QPaintEvent *e )
-{
-  QPainter p;
-  p.begin(this);
-  bool unclipped = testWFlags( WPaintUnclipped );
-  setWFlags( WPaintUnclipped );
-
-  p.setPen(white);
-  p.setRasterOp(XorROP);
-  p.drawLine(e->rect().topLeft(), e->rect().bottomRight());
-
-  if (!unclipped)
-    clearWFlags( WPaintUnclipped );
-  p.end();
-  QWidget::paintEvent(e);
 }
-*/
 
 #include "kexidbform.moc"
