@@ -19,7 +19,7 @@
 #ifndef KIS_IMAGE_NODE_TO_BOTTOM_COMMAND_H_
 #define KIS_IMAGE_NODE_TO_BOTTOM_COMMAND_H_
 
-#include <krita_export.h>
+#include <kritaimage_export.h>
 
 #include "kis_types.h"
 #include "kis_image_command.h"
