@@ -20,8 +20,7 @@
 
 #include <QRect>
 
-#include "KoDocumentSectionModel.h"
-#include <KoProperties.h>
+#include "KisDocumentSectionModel.h"
 
 #include "kis_types.h"
 #include "kis_mask.h"
@@ -45,8 +44,6 @@ public:
     virtual ~KisSelectionMask();
     KisSelectionMask(const KisSelectionMask& rhs);
 
-    bool allowAsChild(KisNodeSP) const;
-
     QIcon icon() const;
 
     KisNodeSP clone() const {
@@ -59,20 +56,27 @@ public:
     bool accept(KisNodeVisitor &v);
     void accept(KisProcessingVisitor &visitor, KisUndoAdapter *undoAdapter);
 
-    virtual KoDocumentSectionModel::PropertyList sectionModelProperties() const;
-    virtual void setSectionModelProperties(const KoDocumentSectionModel::PropertyList &properties);
+    virtual KisDocumentSectionModel::PropertyList sectionModelProperties() const;
+    virtual void setSectionModelProperties(const KisDocumentSectionModel::PropertyList &properties);
 
     void setVisible(bool visible, bool isLoading = false);
     bool active() const;
     void setActive(bool active);
 
+    /**
+     * This method works like the one in KisSelection, but it
+     * compressed the incoming events instead of processing each of
+     * them separately.
+     */
+    void notifySelectionChangedCompressed();
+
 private:
+    Q_PRIVATE_SLOT(m_d, void slotSelectionChangedCompressed());
 
     KisImageWSP image() const;
 
     struct Private;
     Private * const m_d;
-
 };
 
 #endif //_KIS_SELECTION_MASK_
