@@ -24,7 +24,7 @@
 class KisConfigWidgetTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
 
     void testCreation();
 
