@@ -262,11 +262,110 @@ void KisFixedPaintDeviceTest::testBltPerformance()
     << " done in "
     << t.elapsed()
     << "ms";
+}
+
+inline void setPixel(KisFixedPaintDeviceSP dev, int x, int y, quint8 alpha)
+{
+    KoColor c(Qt::black, dev->colorSpace());
+    c.setOpacity(alpha);
+
+    dev->fill(x, y, 1, 1, c.data());
+}
+
+inline quint8 pixel(KisFixedPaintDeviceSP dev, int x, int y)
+{
+    KoColor c(Qt::black, dev->colorSpace());
 
 
+    dev->readBytes(c.data(), x, y, 1, 1);
+    return c.opacityU8();
+}
+
+void KisFixedPaintDeviceTest::testMirroring_data()
+{
+    QTest::addColumn<QRect>("rc");
+    QTest::addColumn<bool>("mirrorHorizontally");
+    QTest::addColumn<bool>("mirrorVertically");
+
+    QTest::newRow("4, false, false") << (QRect(99,99,4,4)) << false << false;
+    QTest::newRow("4, false, true") << (QRect(99,99,4,4)) << false << true;
+    QTest::newRow("4, true, false") << (QRect(99,99,4,4)) << true << false;
+    QTest::newRow("4, true, true") << (QRect(99,99,4,4)) << true << true;
+
+    QTest::newRow("5, false, false") << (QRect(99,99,5,5)) << false << false;
+    QTest::newRow("5, false, true") << (QRect(99,99,5,5)) << false << true;
+    QTest::newRow("5, true, false") << (QRect(99,99,5,5)) << true << false;
+    QTest::newRow("5, true, true") << (QRect(99,99,5,5)) << true << true;
+}
+
+
+void KisFixedPaintDeviceTest::testMirroring()
+{
+    QFETCH(QRect, rc);
+    QFETCH(bool, mirrorHorizontally);
+    QFETCH(bool, mirrorVertically);
+
+    const KoColorSpace *cs = KoColorSpaceRegistry::instance()->rgb8();
+    KisFixedPaintDeviceSP dev = new KisFixedPaintDevice(cs);
+    dev->setRect(rc);
+    dev->initialize();
+
+    KoColor c(Qt::black, cs);
+
+    qsrand(1);
+    int value = 0;
+
+    for (int i = rc.x(); i < rc.x() + rc.width(); i++) {
+        for (int j = rc.y(); j < rc.y() + rc.height(); j++) {
+            setPixel(dev, i, j, value);
+            value = qrand() % 255;
+        }
+        value = qrand() % 255;
+    }
+
+    //dev->convertToQImage(0).save("0_a.png");
+    dev->mirror(mirrorHorizontally, mirrorVertically);
+    //dev->convertToQImage(0).save("0_b.png");
+
+    int startX;
+    int endX;
+    int incX;
+
+    int startY;
+    int endY;
+    int incY;
+
+    if (mirrorHorizontally) {
+        startX = rc.x() + rc.width() - 1;
+        endX = rc.x() - 1;
+        incX = -1;
+    } else {
+        startX = rc.x();
+        endX = rc.x() + rc.width();
+        incX = 1;
+    }
+
+    if (mirrorVertically) {
+        startY = rc.y() + rc.height() - 1;
+        endY = rc.y() - 1;
+        incY = -1;
+    } else {
+        startY = rc.y();
+        endY = rc.y() + rc.height();
+        incY = 1;
+    }
+
+    qsrand(1);
+    value = 0;
+
+    for (int i = startX; i != endX ; i += incX) {
+        for (int j = startY; j != endY; j += incY) {
+            QCOMPARE(pixel(dev, i, j), (quint8)value);
+            value = qrand() % 255;
+        }
+        value = qrand() % 255;
+    }
 }
 
 QTEST_KDEMAIN(KisFixedPaintDeviceTest, GUI)
 #include "kis_fixed_paint_device_test.moc"
-
-
