@@ -23,10 +23,9 @@
 #include <KoColor.h>
 #include <KoAbstractGradient.h>
 
-KisPressureGradientOption::KisPressureGradientOption(): KisCurveOption(i18n("Gradient"), "Gradient", KisPaintOpOption::generalCategory(), false)
+KisPressureGradientOption::KisPressureGradientOption()
+    : KisCurveOption("Gradient", KisPaintOpOption::GENERAL, false)
 {
-    setMinimumLabel(i18n("0%"));
-    setMaximumLabel(i18n("100%"));
 }
 
 void KisPressureGradientOption::apply(KoColor& color, const KoAbstractGradient* gradient, const KisPaintInformation& info) const
