@@ -30,6 +30,16 @@
 #include "testutil.h"
 #include "KisPart.h"
 
+#include <filter/kis_filter_registry.h>
+#include <generator/kis_generator_registry.h>
+
+
+void KisKraLoaderTest::initTestCase()
+{
+    KisFilterRegistry::instance();
+    KisGeneratorRegistry::instance();
+}
+
 void KisKraLoaderTest::testLoading()
 {
     KisDocument *doc = KisPart::instance()->createDocument();
@@ -56,11 +66,14 @@ void KisKraLoaderTest::testLoading()
     delete doc;
 }
 
-
-
-void KisKraLoaderTest::testObligeSingleChild()
+void testObligeSingleChildImpl(bool transpDefaultPixel)
 {
-    QString fileName = TestUtil::fetchDataFileLazy("single_layer_no_channel_flags.kra");
+
+    QString id = !transpDefaultPixel ?
+        "single_layer_no_channel_flags_nontransp_def_pixel.kra" :
+        "single_layer_no_channel_flags_transp_def_pixel.kra";
+
+    QString fileName = TestUtil::fetchDataFileLazy(id);
 
     KisDocument *doc = KisPart::instance()->createDocument();
     doc->loadNativeFormat(fileName);
@@ -75,11 +88,26 @@ void KisKraLoaderTest::testObligeSingleChild()
     QVERIFY(child);
 
     QCOMPARE(root->original(), root->projection());
-    QCOMPARE(root->original(), child->projection());
+
+    if (transpDefaultPixel) {
+        QCOMPARE(root->original(), child->projection());
+    } else {
+        QVERIFY(root->original() != child->projection());
+    }
 
     delete doc;
 }
 
+void KisKraLoaderTest::testObligeSingleChild()
+{
+    testObligeSingleChildImpl(true);
+}
+
+void KisKraLoaderTest::testObligeSingleChildNonTranspPixel()
+{
+    testObligeSingleChildImpl(false);
+}
+
 
 QTEST_KDEMAIN(KisKraLoaderTest, GUI)
 #include "kis_kra_loader_test.moc"
