@@ -20,22 +20,17 @@
  */
 
 #include "KoPADocumentStructureDocker.h"
+
 #include "KoPADocumentModel.h"
 #include "KoPADocument.h"
 #include "KoPAPageBase.h"
 #include "KoPACanvas.h"
-#include "KoPAView.h"
-#include "KoPAMasterPage.h"
-#include "KoPAPage.h"
-#include "commands/KoPAPageInsertCommand.h"
-#include "commands/KoPAPageDeleteCommand.h"
+#include "KoPAViewBase.h"
 
 #include <KoShapeManager.h>
-#include <KoShapeContainer.h>
 #include <KoToolManager.h>
 #include <KoCanvasBase.h>
 #include <KoCanvasController.h>
-#include <KoShapeBasedDocumentBase.h>
 #include <KoSelection.h>
 #include <KoShapeOdfSaveHelper.h>
 #include <KoPAOdfPageSaveHelper.h>
@@ -327,7 +322,7 @@ void KoPADocumentStructureDocker::addLayer()
                 layer->setZIndex(layers.last()->zIndex() + 1);
             }
             KUndo2Command *cmd = new KoShapeCreateCommand(m_doc, layer, 0);
-            cmd->setText(i18nc("(qtundo-format)", "Create Layer"));
+            cmd->setText(kundo2_i18n("Create Layer"));
             m_doc->addCommand(cmd);
             m_model->update();
         }
@@ -353,7 +348,7 @@ void KoPADocumentStructureDocker::deleteItem()
                 deleteShapes.append(page);
             }
             cmd = new KoShapeDeleteCommand(m_doc, deleteShapes);
-            cmd->setText(i18nc("(qtundo-format)", "Delete Layer"));
+            cmd->setText(kundo2_i18n("Delete Layer"));
         }
         else {
             KMessageBox::error(0, i18n("Could not delete all layers. At least one layer is required."), i18n("Error deleting layers"));
