@@ -20,7 +20,7 @@
 #include <KPrAboutData.h>
 
 #include <KoApplication.h>
-
+#include "KPrDocument.h"
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
@@ -36,7 +36,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
     options.add("+[file]", ki18n("File to open"));
     KCmdLineArgs::addCmdLineOptions( options );
 
-    KoApplication app;
+    KoApplication app(STAGE_MIME_TYPE);
 
     if (!app.start())
         return 1;
